summaryrefslogtreecommitdiff
path: root/deps/npm/node_modules/ci-info/index.js
diff options
context:
space:
mode:
Diffstat (limited to 'deps/npm/node_modules/ci-info/index.js')
-rw-r--r--deps/npm/node_modules/ci-info/index.js40
1 files changed, 25 insertions, 15 deletions
diff --git a/deps/npm/node_modules/ci-info/index.js b/deps/npm/node_modules/ci-info/index.js
index e716e34b31..74750a7c06 100644
--- a/deps/npm/node_modules/ci-info/index.js
+++ b/deps/npm/node_modules/ci-info/index.js
@@ -4,26 +4,36 @@ var env = process.env
var vendors = [
// Constant, Name, Envs
- ['TRAVIS', 'Travis CI', 'TRAVIS'],
- ['CIRCLE', 'CircleCI', 'CIRCLECI'],
- ['GITLAB', 'GitLab CI', 'GITLAB_CI'],
['APPVEYOR', 'AppVeyor', 'APPVEYOR'],
+ ['BAMBOO', 'Bamboo', 'bamboo_planKey'],
+ ['BITBUCKET', 'Bitbucket Pipelines', 'BITBUCKET_COMMIT'],
+ ['BUILDKITE', 'Buildkite', 'BUILDKITE'],
+ ['CIRCLE', 'CircleCI', 'CIRCLECI'],
+ ['CIRRUS', 'Cirrus CI', 'CIRRUS_CI'],
+ ['CODEBUILD', 'AWS CodeBuild', 'CODEBUILD_BUILD_ARN'],
['CODESHIP', 'Codeship', {CI_NAME: 'codeship'}],
['DRONE', 'Drone', 'DRONE'],
+ ['GITLAB', 'GitLab CI', 'GITLAB_CI'],
+ ['GOCD', 'GoCD', 'GO_PIPELINE_LABEL'],
+ ['HUDSON', 'Hudson', 'HUDSON_URL'],
+ ['JENKINS', 'Jenkins', 'JENKINS_URL', 'BUILD_ID'],
['MAGNUM', 'Magnum CI', 'MAGNUM'],
['SEMAPHORE', 'Semaphore', 'SEMAPHORE'],
- ['JENKINS', 'Jenkins', 'JENKINS_URL', 'BUILD_ID'],
- ['BAMBOO', 'Bamboo', 'bamboo_planKey'],
- ['TFS', 'Team Foundation Server', 'TF_BUILD'],
- ['TEAMCITY', 'TeamCity', 'TEAMCITY_VERSION'],
- ['BUILDKITE', 'Buildkite', 'BUILDKITE'],
- ['HUDSON', 'Hudson', 'HUDSON_URL'],
+ ['SHIPPABLE', 'Shippable', 'SHIPPABLE'],
+ ['SOLANO', 'Solano CI', 'TDDIUM'],
+ ['STRIDER', 'Strider CD', 'STRIDER'],
['TASKCLUSTER', 'TaskCluster', 'TASK_ID', 'RUN_ID'],
- ['GOCD', 'GoCD', 'GO_PIPELINE_LABEL'],
- ['BITBUCKET', 'Bitbucket Pipelines', 'BITBUCKET_COMMIT'],
- ['CODEBUILD', 'AWS CodeBuild', 'CODEBUILD_BUILD_ARN']
+ ['TDDIUM', 'Solano CI', 'TDDIUM'], // Deprecated
+ ['TEAMCITY', 'TeamCity', 'TEAMCITY_VERSION'],
+ ['TFS', 'Team Foundation Server', 'TF_BUILD'],
+ ['TRAVIS', 'Travis CI', 'TRAVIS']
]
+// Used for testinging only
+Object.defineProperty(exports, '_vendors', {
+ value: vendors.map(function (v) { return v[0] })
+})
+
exports.name = null
vendors.forEach(function (vendor) {
@@ -40,9 +50,9 @@ vendors.forEach(function (vendor) {
})
exports.isCI = !!(
- env.CI || // Travis CI, CircleCI, Gitlab CI, Appveyor, CodeShip
- env.CONTINUOUS_INTEGRATION || // Travis CI
- env.BUILD_NUMBER || // Jenkins, TeamCity
+ env.CI || // Travis CI, CircleCI, Cirrus CI, Gitlab CI, Appveyor, CodeShip
+ env.CONTINUOUS_INTEGRATION || // Travis CI, Cirrus CI
+ env.BUILD_NUMBER || // Jenkins, TeamCity
exports.name ||
false
)